@@ -2,6 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 import datetime
 from decimal import Decimal
+from collections import defaultdict
 
 from trytond.model import ModelView, fields
 from trytond.pool import Pool, PoolMeta
@@ -11,10 +12,10 @@ from trytond.tools import grouped_slice
 
 __all__ = ['Configuration', 'Production',
     'CreateProductionRequestStart', 'CreateProductionRequest']
-__metaclass__ = PoolMeta
 
 
 class Configuration:
+    __metaclass__ = PoolMeta
     __name__ = 'production.configuration'
     supply_period = fields.Property(fields.Numeric('Supply Period',
             digits=(16, 0), help='In number of days', required=True))
@@ -25,6 +26,7 @@ class Configuration:
 
 
 class Production:
+    __metaclass__ = PoolMeta
     __name__ = 'production'
 
     @classmethod
@@ -91,8 +93,8 @@ class Production:
                 for p in sub_products)
 
             for warehouse in warehouses:
-                quantities = dict((x, pbl.pop((warehouse.id, x), 0))
-                    for x in product_ids)
+                quantities = defaultdict(lambda: 0,
+                    ((x, pbl.pop((warehouse.id, x), 0)) for x in product_ids))
                 shortages = cls.get_shortage(warehouse.id, product_ids, today,
                     quantities, products_period, product2ops)
 
